#!/usr/bin/ruby
require 'gsl'
include GSL

dim = 2

func = Proc.new { |t, y, dydt, mu|
  dydt[0] = y[1]
  dydt[1] = -y[0] - mu*y[1]*(y[0]*y[0] - 1.0)
}

jac = Proc.new { |t, y, dfdy, dfdt, mu|
  dfdy.set(0, 0, 0.0)
  dfdy.set(0, 1, 1.0)
  dfdy.set(1, 0, -2*mu*y[0]*y[1] - 1.0)
  dfdy.set(1, 1, -mu*(y[0]*y[0] - 1.0))
  dfdt[0] = 0.0
  dfdt[1] = 0.0
}
s = Odeiv::Step.new(GSL::Odeiv::RKF45, dim)
#s = Odeiv::Step.new(BSIMP, dim)
#p s.name
#p s.order

c = Odeiv::Control.y_new(1e-6, 0.0)

e = Odeiv::Evolve.new(dim)

#sys = Odeiv::System.new(func, jac, dim)
#sys = Odeiv::System.new(func, nil, dim)
sys = Odeiv::System.new(func, dim)
p sys

mu = 10.0
sys.set_params(mu)

t = 0.0; tend = 100.0
h = 1e-6
y = Vector.new([1.0, 0.0])

GSL::ieee_env_setup()

while t < tend
  status = e.apply(c, s, sys, t, tend, h, y)

  break if status != GSL::SUCCESS

  printf("%.5e %.5e %.5e %.5e\n", t, y[0], y[1], h)
end

