#!/usr/bin/ruby
require 'gsl'

dim = 2

func = Proc.new { |t, y, dydt, mu|
  dydt[0] = y[1]
  dydt[1] = -y[0] - mu*y[1]*(y[0]*y[0] - 1.0)
}

jac = Proc.new { |t, y, dfdy, dfdt, mu|
  dfdy.set(0, 0, 0.0)
  dfdy.set(0, 1, 1.0)
  dfdy.set(1, 0, -2*mu*y[0]*y[1] - 1.0)
  dfdy.set(1, 1, -mu*(y[0]*y[0] - 1.0))
  dfdt[0] = 0.0
  dfdt[1] = 0.0
}

#gos = Odeiv::Solver.new(STEP_RK8PD, [1e-6, 0.0, 1, 0], func, jac, dim)
#gos = Odeiv::Solver.new(STEP_RK8PD, [1e-6, 0.0, 1, 0], func, nil, dim)
#gos = Odeiv::Solver.new(STEP_RK8PD, [1e-6, 0.0], func, nil, dim)
#gos = Odeiv::Solver.new(Odeiv::STEP_RKF45, [1e-6, 0.0], func, jac, dim)
#gos = Odeiv::Solver.new(Odeiv::STEP_RKF45, [1e-6, 0.0], func, nil, dim)
gos = Odeiv::Solver.new(Odeiv::STEP_BSIMP, [1e-6, 0.0], func, jac, dim)
gos.set_params(10.0)

#p gos.step.name
#s = Odeiv::Step.new(Odeiv::STEP_RKCK, dim)
#gos.set_step(s)
#p gos.step.name
#p gos.control.name

t = 0.0; tend = 100.0
h = 1e-6
y = Vector.new([1.0, 0.0])

GSL::ieee_env_setup()

while t < tend
  status = gos.apply(t, tend, h, y)

  break if status != GSL::SUCCESS

  printf("%.5e %.5e %.5e %.5e\n", t, y[0], y[1], h)
end

